@@ -1,6 +1,9 @@
 from __future__ import unicode_literals
+
 from . import _filters, _ffmpeg, _run
 from ._filters import *
 from ._ffmpeg import *
 from ._run import *
-__all__ = _filters.__all__ + _ffmpeg.__all__ + _run.__all__
+from ._view import *
+
+__all__ = _filters.__all__ + _ffmpeg.__all__ + _run.__all__ + _view.__all__
